<?php
/**
 * @author ElisDN <mail@elisdn.ru>
 * @link http://www.elisdn.ru/blog/58/old-posts-promotion-on-twitter
 * @version 1.0
 */

namespace Parser;

use Cache\Cache;

class CachedHTMLPage implements Page
{
	private $page;
	private $cache;
	private $data = [
		'h1' => '',
		'title' => '',
		'description' => '',
		'keywords' => '',
	];

	public function __construct(Page $page, Cache $cache) {
		$this->page = $page;
		$this->cache = $cache;
	}

	public function load($url) {
		$key = $this->generateCacheKey($url);
		if ($this->cache->has($key)) {
			$this->data = unserialize($this->cache->get($key));
			return true;
		} else {
			$load = $this->page->load($url);
			$data = [
				'h1' => $this->page->getH1(),
				'title' => $this->page->getTitle(),
				'description' => $this->page->getDescription(),
				'keywords' => $this->page->getKeywords(),
			];
			$this->cache->set($key, serialize($data));
			$this->data = $data;
			return $load;
		}
	}

	public function getH1() {
		return $this->data['h1'];
	}

	public function getTitle() {
		return $this->data['title'];
	}

	public function getDescription() {
		return $this->data['description'];
	}

	public function getKeywords() {
		return $this->data['keywords'];
	}

	private function generateCacheKey($url) {
		return 'page_' . md5($url);
	}
}